@@ -1,40 +1,38 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\ 
- *  epix.h -- Automatically created on Tue Sep 17 03:10:32 EDT 2002  * 
+ *  epix.h -- Automatically created on Mon Dec 22 22:19:20 EST 2003  * 
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */ 
 
+/* 
+ * globals.h -- Top-level header file
+ *
+ * This file is part of ePiX, a preprocessor for creating high-quality 
+ * line figures in LaTeX 
+ *
+ * Version 0.8.8a
+ */
+
+/* 
+ * Copyright (C) 2001, 2002  
+ * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
+ * Department of Mathematics and Computer Science
+ * College of the Holy Cross
+ * Worcester, MA, 01610-2395, USA
+ */
+
 /*
- * globals.h -- ePiX top-level header file
- *
- * ePiX: A lightweight LaTeX pre-processor to generate mathematically 
- * accurate eepic files from user-friendly C source files. ePiX is
- * implemented as a C/C++ library and a shell script, and requires a C++ 
- * compiler for ordinary use. The GNU compiler is strongly preferred.
- *
- * Feedback about this program (bug reports, suggestions for features,
- * etc.) is welcome. If you find this program useful, please consider
- * making a contribution to the Free Software Foundation; see
- * http://www.fsf.org
- *
- * Version 0.8.6
- * Last Change: July 28, 2002
- *
- * Copyright (C) 2001--2, Andrew D. Hwang   <ahwang@mathcs.holycross.edu>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * ePiX is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * ePiX is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+ * License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- * 
+ * along with ePiX; if not, write to the Free Software Foundation, Inc.,
+ * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #define _EPIX
@@ -43,6 +41,8 @@
 #include <stdlib.h>
 #include <math.h>
 
+namespace ePiX {
+
 
 /* 
  * To find hardwired constants in the source code, do
@@ -52,17 +52,17 @@
 
 /* * * Tweakable constants * * */
 
-#define EPIX_NUM_PTS 40     /* Number of points in half-ellipses, splines */
-#define EPIX_FILE_WIDTH 70  /* Width of output file, in characters */
-#define EPIX_SPOT_DIAM 4    /* Diameter of circles and spots in true pt */
-#define EPIX_ARROWHEAD_WIDTH 1.5 /* Half-width of arrowheads in true pt */
-#define EPIX_ARROWHEAD_RATIO 5.5 /* Aspect ratio of arrowheads */
+const int EPIX_NUM_PTS=40;     /* Number of points in half-ellipses, splines */
+const int EPIX_FILE_WIDTH=70;  /* Width of output file, in characters */
+const double EPIX_SPOT_DIAM=4; /* Diameter of circles and spots in true pt */
+const double EPIX_ARROWHEAD_WIDTH=1.5; /* Half-width of arrowheads in pt */
+const double EPIX_ARROWHEAD_RATIO=5.5; /* Aspect ratio of arrowheads */
 
 /* 
  * Determines accuracy of truncation in clipplot et. al.
  * smaller -> better accuracy, longer run
  */
-#define EPIX_SEEK_SIZE 0.01 
+const double EPIX_SEEK_SIZE=0.01;
 
 /*
  * In calculus plotting, determines the size of the increment dt
@@ -72,11 +72,11 @@
  *
  * larger -> better accuracy, longer run
  */
-#define EPIX_ITERATIONS 200
+const int EPIX_ITERATIONS=200;
 
 /* Dash length/dot separation parameters */
-#define EPIX_DASH_LENGTH 5.0 
-#define EPIX_DOT_SEP 40.0
+const double EPIX_DASH_LENGTH=5.0;
+const double EPIX_DOT_SEP=40.0;
 
 /* * * End of tweakable constans * * */
 
@@ -97,9 +97,9 @@ enum epix_field_type {SLOPE, DART, VECTOR};
 
 /* Deprecated constants */
 
-#define EPIX_PAIRS_PER_LINE 4  /* Number of pairs per line in output file */
-#define EPIX_MAX_LINES 20000   /* Fatal error if this many lines printed */
-extern int epix_lines_printed; /* output counter */
+const int EPIX_PAIRS_PER_LINE=4;/* Number of pairs per line in output file */
+const int EPIX_MAX_LINES=20000; /* Fatal error if this many lines printed */
+extern int epix_lines_printed;  /* output counter */
 
 /* 
  * ePiX depicts the rectangle [x_min, x_max] x [y_min, y_max] in a LaTeX
@@ -140,18 +140,22 @@ extern double x_size, y_size;
 extern double pic_size; // e.g., 1
 extern char *pic_unit;  // e.g., "pt" 
 
+} /* end of namespace */
+
 /* 
  * pairs.h -- ePiX pair:: class and mathematical operators
  *
  * Andrew D. Hwang                      <ahwang@mathcs.holycross.edu>
  *
- * Version: 0.8.5
- * Last Change: July 5, 2002
+ * Version: 0.8.8rc6
+ * Last Change: December 02, 2002
  */
 
 #define _EPIX_PAIRS
 
 
+using namespace std;
+
 class pair 
 {
  public:
@@ -178,7 +182,7 @@ class pair
   // complex multiplication and division
   pair& operator *= (const pair&);
   pair& operator /= (const pair&);
-};
+}; /* end of pair class */
 
 /* pair creation */
 pair P(double, double); 
@@ -235,13 +239,15 @@ pair mult_pair(pair, pair);
  *
  * Andrew D. Hwang                      <ahwang@mathcs.holycross.edu>
  *
- * Version: 0.8.6rc6
- * Last Change: July 28, 2002
+ * Version: 0.8.8rc6
+ * Last Change: December 02, 2002
  */
 
 #define _EPIX_TRIPLES
 
 
+using namespace std;
+
 class triple 
 {
  public:
@@ -269,7 +275,7 @@ class triple
   // complex multiplication and division
   triple& operator *= (const triple&);
   triple& operator /= (const triple&);
-};
+}; /* end of class */
 
 /* triple creation */
 triple P(double, double, double); 
@@ -281,6 +287,8 @@ const triple E_1 = P(1,0,0);
 const triple E_2 = P(0,1,0);
 const triple E_3 = P(0,0,1);
 
+pair V(triple); // Project <triple> according to current viewpoint
+
 int  operator == (const triple&, const triple&);
 triple operator - (const triple&);
 triple operator + (const triple&, const triple&);
@@ -306,8 +314,8 @@ void rot3(const double& angle);
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.3
- * Last Change: June 14, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
@@ -348,6 +356,10 @@ void rot3(const double& angle);
 
 #include <string.h>
 
+namespace ePiX {
+
+  using namespace std;
+
 /* If less than 0.0001, set to zero */
 double truncate(double);
 
@@ -380,20 +392,27 @@ double true_len(pair); // length in true pt
 
 pair normalize(pair); // parallel true pt unit vector
 
+} /* end of namespace */
+
 /*
  * output.h -- ePiX file-formatting output routines
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc5
- * Last Change: July 27, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
 #define _EPIX_OUTPUT
 
 
+namespace ePiX {
+
+  using namespace std;
+
 extern int EPIX_PATH_STYLE;
+extern double epix_stretch_factor;
 
 /* Sectioning Functions */
 
@@ -474,18 +493,30 @@ void cmyk(double c, double m, double y, double k);
 #define yellow    fprintf (stdout, "\n\\color[cmyk]{0,0,1,0}")
 #define black     fprintf (stdout, "\n\\color[cmyk]{0,0,0,1}")
 
+/* 
+ * depth of gray in shaded objects; argument is an integer from 0
+ * (white) to 32 (black) 
+ */
+void gray(double);
+
+} /* end of namespace */
+
 /* 
  * objects.h -- Simple picture objects: axes, grids, markers, polygons
  *
  * Andrew D. Hwang                      <ahwang@mathcs.holycross.edu>
  *
- * Version: 0.8.6rc4
- * Last Change: July 26, 2002
+ * Version: 0.8.8rc6
+ * Last Change: December 02, 2002
  */
 
 #define _EPIX_OBJECTS
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
  *                    Picture objects                    *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -516,6 +547,7 @@ void ring(pair, double); // unfilled circ of specified diam
 void spot(pair);
 void dot(pair);
 void ddot(pair);
+void dot(pair, double); // filled circ of specified diam
 
 /* Axes and coordinate grids. */
 
@@ -614,19 +646,25 @@ void draw_bolddart(pair, pair);
 void dart(pair, pair);
 void bolddart(pair, pair);
 
+} /* end of namespace */
+
 /*
  * curves.h -- Ellipses, arcs, splines
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc2
- * Last Change: July 24, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
 #define _EPIX_CURVES
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
  *  Ellipses, half-ellipses, circular arcs, splines -- curves.c  *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -679,18 +717,24 @@ void p_twist (pair, pair);
 void n_twist (pair, pair);
 void twists (pair, pair, int);
 
+} /* end of namespace */
+
 /*
  * plots.h 
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc6
- * Last Change: July 28, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  */
 
 #define _EPIX_PLOTS
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
  *          Plots of user-specified functions -- plots.c         *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -880,18 +924,35 @@ void flow_plot(pair F(double, double), pair f(double),
 	       triple color(double), double, int, int);
 void flow_plot(pair F(double, double), pair f(double), double, int, int);
 
+/* Jay Belanger's shaded plot routines -- December 1, 2002 */
+
+void blackplot(double f(double), double, double, int);
+void blackplot(double f1(double), double f2(double), double, double, int);
+
+void whiteplot(double f(double), double, double, int);
+void whiteplot(double f1(double), double f2(double), double, double, int);
+
+void shadeplot(double f(double), double, double, int);
+void shadeplot(double f1(double), double f2(double), double, double, int);
+
+} /* end of namespace */
+
 /*
  * geometry.h 
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc5
- * Last Change: July 27, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  */
 
 #define _EPIX_GEOMETRY
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* Radial projection from origin to unit sphere */
 void plot_R      (double f1(double), double f2(double), double f3(double), 
 		  double t_min, double t_max, int num_pts);
@@ -928,22 +989,29 @@ void hyperbolic_line (pair, pair);
 void draw_disk_line (pair, pair);
 void disk_line (pair, pair);
 
+} /* end of namespace */
+
 /*
  * arcana.h
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc2
- * Last Change: July 24, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
 #define _EPIX_ARCANA
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* Implementation of the momentum construction */
 void draw_profile (double f(double), double, double, int);
 void plot_profile (double f(double), double, double, int);
+void plot_profile (double f(double), double, double, double, int);
 
 /* Plane linear transformations */
 pair 
@@ -972,19 +1040,25 @@ std_F (pair, pair);
 void 
 fractal (pair p, pair q, int depth, const int *pre_seed);
 
+} /* end of namespace */
+
 /*
  * meshplots.h
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.8.6rc5
- * Last Change: July 27, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
 #define _EPIX_MESH
 
 
+namespace ePiX {
+
+  using namespace std;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
  *                        meshplots.cc                           *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -1005,18 +1079,24 @@ void wiremesh(double f(double, double), pair, pair, mesh, mesh);
 void draw_wiremesh(triple Phi(double, double), pair, pair, mesh, mesh);
 void wiremesh     (triple Phi(double, double), pair, pair, mesh, mesh);
 
+} /* end of namespace */
+
 /*
  * functions.h
  *
  * Andrew D. Hwang            <ahwang@mathcs.holycross.edu>
  *
- * Version 0.7.x
- * Last Change: May 29, 2002
+ * Version 0.8.8rc6
+ * Last Change: December 02, 2002
  *
  */
 
 #define _EPIX_FUNCTIONS
 
+namespace ePiX {
+
+  using namespace std;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
  *                         functions.c                           *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -1042,9 +1122,6 @@ recip (double);
 double
 cb (double);
 
-int 
-abs (int);
-
 int 
 gcd (int, int);
 
@@ -1054,3 +1131,5 @@ inf (double f(double), double, double);
 double
 sup (double f(double), double, double);
 
+} /* end of namespace */
+
